#!/bin/bash
export DEBIAN_FRONTEND=noninteractive

set -x
exec 1> >(tee -a /var/log/sandboxbuild.log) 2>&1

PKGS="
    apt-utils
    bind9-host
    bonnie++
    build-essential
    byobu
    command-not-found
    daemontools
    debmirror
    default-jre
    docker
    fonts-indic
    fonts-ipafont-gothic
    fonts-ipafont-mincho
    fortune
    git
    irssi
    jq
    ldap-auth-client
    ldap-utils
    libnss-mdns
    libxml2
    libxml2-dev
    libxslt1-dev
    lsof
    mailutils
    make
    man-db
    mosh
    mutt
    nmap
    nodejs
    npm
    nscd
    pbzip2
    pv
    pwgen
    python
    python-dev
    python-pip
    rbenv
    rsync
    rsyslog
    rsyslog-gnutls
    rsyslog-relp
    runit
    screen
    snmp
    snmpd
    software-properties-common
    telnet
    texlive-latex-base
    tmux
    ttf-wqy-microhei
    ttf-wqy-zenhei
    vagrant
    vim
    wamerican-insane
    wget
"

apt-get update
apt-get -y upgrade
apt-get install -y $PKGS

add-apt-repository ppa:neovim-ppa/unstable
apt-get update
sudo apt-get install neovim

# use faster one:
OLD="$(which bzip2)"
rm $OLD
ln $(which pbzip2) $OLD

git clone https://github.com/rbenv/ruby-build.git /root/.rbenv/plugins/ruby-build

rbenv install 2.3.0
rbenv install jruby-9.0.5.0

GEMS="
    bundler
"

for GEM in $GEMS ; do
    gem install -V $GEM
done

cd /usr/local/bin
wget https://raw.githubusercontent.com/sneak/ppss/master/ppss
chmod +x ./ppss

NPM_PKGS="
    coffee-script
    coffeelint
"

# update npm
npm update -g --loglevel info npm
for PKG in $NPM_PKGS ; do
    npm install -g --loglevel info $PKG
done

PIP_PKGS="
    virtualenv
    pylint
    awscli
"

pip install --upgrade pip
pip install setuptools
pip install pip-review
pip-review --verbose --auto
for PKG in $PIP_PKGS; do
    pip install $PKG
done

# cleanup

rm -rf \
    /root/.cache \
    /var/cache/* \
    /var/lib/apt/lists/* \
    /core
